@@ -10,8 +10,7 @@ SELECT pgl_ddl_deploy.deploy('testspecial');
 CREATE TEMP VIEW tables_in_replication AS 
 SELECT COUNT(1)
 FROM pgl_ddl_deploy.rep_set_table_wrapper() t
-INNER JOIN pglogical.replication_set rs USING (set_id)
-WHERE rs.set_name = 'testspecial';
+WHERE t.name = 'testspecial' AND NOT relid::REGCLASS::TEXT = 'pgl_ddl_deploy.queue';
 
 TABLE tables_in_replication;
 
@@ -41,3 +40,15 @@ In <= 1.5, returned this:
  {"DROP SCHEMA","DROP TABLE","DROP FUNCTION","DROP TYPE","DROP VIEW","DROP SEQUENCE"}
 (1 row)
 */
+
+SET client_min_messages TO warning;
+DROP OWNED BY test_pgl_ddl_deploy;
+DROP ROLE test_pgl_ddl_deploy;
+DROP ROLE unpriv;
+DROP EXTENSION pgl_ddl_deploy CASCADE;
+DROP EXTENSION IF EXISTS pglogical CASCADE;
+DROP SCHEMA IF EXISTS pglogical CASCADE;
+DROP TABLE IF EXISTS tmp_objs;
+DROP SCHEMA IF EXISTS special CASCADE;
+DROP SCHEMA IF EXISTS bla CASCADE;
+DROP SCHEMA IF EXISTS pgl_ddl_deploy CASCADE;
